@@ -12,19 +12,21 @@ class Signatures:
     def __init__(self):
         self.last_signature: int = -1
 
-    def get_signature(self, buffer) -> int:
+    def get_signature(self, buffer, file_version: int = -1) -> int:
         signature = Signatures.NONE
-        if re.match(b'\x00\x00?\x00', buffer[1:5]):  # SC Dict size
+        if self.last_signature == Signatures.SC and file_version == 1:
             signature = Signatures.LZMA
-        elif self.last_signature == Signatures.SC:
+            self.last_signature = -1
+        elif self.last_signature == Signatures.SC and file_version == 2:
             signature = Signatures.ZSTD
             self.last_signature = -1
 
-        if buffer.startswith(b'SC'):
-            if len(buffer) >= 30 and buffer[26:30] == b'SCLZ':
-                signature = Signatures.SCLZ
-            else:
-                signature = Signatures.SC
+        if re.match(b'\x00\x00?\x00', buffer[1:5]):
+            signature = Signatures.LZMA
+        if buffer.startswith(b'SCLZ'):
+            signature = Signatures.SCLZ
+        elif buffer.startswith(b'SC'):
+            signature = Signatures.SC
         elif buffer[:4] == b'Sig:':
             signature = Signatures.SIG
 
